@@ -39,7 +39,7 @@
 #include <KLocalizedString>
 
 #include <QVariant>
-#include <QDate>
+#include <QIcon>
 
 using namespace GpgME;
 using namespace Kleo;
@@ -75,7 +75,7 @@ public:
     {
         mItemData << i18n("ID")
                   << i18n("Name")
-                  << i18n("EMail")
+                  << i18n("E-Mail")
                   << i18n("Valid From")
                   << i18n("Valid Until")
                   << i18n("Status");
@@ -122,6 +122,22 @@ public:
         return mItemData.value(column);
     }
 
+    QVariant toolTip(int column) const
+    {
+        if (column == 5 /*Status*/) {
+            return i18n("class %1", mSig.certClass());
+        }
+        return mItemData.value(column);
+    }
+
+    QVariant icon(int column) const
+    {
+        if (!mSig.isNull() && column == 5 /*Status*/) {
+            return Formatting::validityIcon(mSig);
+        }
+        return QVariant();
+    }
+
     int row() const
     {
         if (mParentItem) {
@@ -148,7 +164,7 @@ public:
 private:
     QList<UIDModelItem*> mChildItems;
     QList<QVariant> mItemData;
-    UIDModelItem *mParentItem;
+    UIDModelItem *mParentItem = nullptr;
     UserID::Signature mSig;
     UserID mUid;
 };
@@ -204,7 +220,7 @@ int UserIDListModel::columnCount(const QModelIndex &parent) const
 
 int UserIDListModel::rowCount(const QModelIndex &parent) const
 {
-    UIDModelItem *parentItem;
+    UIDModelItem *parentItem = nullptr;
     if (parent.column() > 0 || !mRootItem) {
         return 0;
     }
@@ -224,7 +240,7 @@ QModelIndex UserIDListModel::index(int row, int column, const QModelIndex &paren
         return QModelIndex();
     }
 
-    UIDModelItem *parentItem;
+    UIDModelItem *parentItem = nullptr;
 
     if (!parent.isValid()) {
         parentItem = mRootItem;
@@ -271,12 +287,21 @@ QVariant UserIDListModel::data(const QModelIndex &index, int role) const
         return QVariant();
     }
 
-    if (role != Qt::DisplayRole && role != Qt::EditRole && role != Qt::ToolTipRole) {
+    if (role != Qt::DisplayRole && role != Qt::EditRole && role != Qt::ToolTipRole &&
+        role != Qt::DecorationRole) {
         return QVariant();
     }
 
     UIDModelItem *item = static_cast<UIDModelItem*>(index.internalPointer());
 
+    if (role == Qt::ToolTipRole) {
+        return item->toolTip(index.column());
+    }
+
+    if (role == Qt::DecorationRole) {
+        return item->icon(index.column());
+    }
+
     return item->data(index.column());
 }
 
